@@ -4,12 +4,15 @@
 {-# LANGUAGE Trustworthy                #-}
 module Data.Semialign.Internal where
 
-import Prelude ()
-import Prelude.Compat hiding (repeat, unzip, zip, zipWith)
+import Prelude
+       (Bool (..), Eq (..), Functor (fmap), Maybe (..), Monad (..), Ord (..),
+       Ordering (..), String, error, flip, fst, id, maybe, snd, uncurry, ($),
+       (++), (.))
 
-import qualified Prelude.Compat as Prelude
+import qualified Prelude as Prelude
 
-import Control.Applicative               (ZipList (..))
+import Control.Applicative (ZipList (..), pure, (<$>))
+import Data.Monoid         (Monoid (..))
 import Data.Bifunctor                    (Bifunctor (..))
 import Data.Functor.Compose              (Compose (..))
 import Data.Functor.Identity             (Identity (..))
@@ -267,12 +270,12 @@ class Semialign f => Unalign f where
 -- but the right hand side is @[('That' 0, 'These' 0 0)]@.
 --
 class Semialign f => Zip f where
-    -- | Combines to structures by taking the intersection of their shapes
+    -- | Combines two structures by taking the intersection of their shapes
     -- and using pair to hold the elements.
     zip :: f a -> f b -> f (a, b)
     zip = zipWith (,)
     --
-    -- | Combines to structures by taking the intersection of their shapes
+    -- | Combines two structures by taking the intersection of their shapes
     -- and combining the elements with the given function.
     zipWith :: (a -> b -> c) -> f a -> f b -> f c
     zipWith f a b = uncurry f <$> zip a b
